// ldvinterface.h
// LiVES
// (c) G. Finch 2006 <salsaman@gmail.com>
// released under the GNU GPL 3 or later
// see file ../COPYING for licensing details

#include "ldvgrab.h"

struct _dvgrabw * create_camwindow (s_cam *cam, int type);
void show_camfilesel(void);



